NodeDataRef

Struct NodeDataRef 

pub struct NodeDataRef<T> { /* private fields */ }
Holds a strong reference to a node, but dereferences to some component inside of it.

Implementations

Source

impl<T> NodeDataRef<T>

Core methods for NodeDataRef.

Provides construction and access methods for typed references to node data.

pub fn new<F>(rc: NodeRef, f: F) -> NodeDataRef<T>
where F: FnOnce(&Node) -> &T,

Create a NodeDataRef for a component in a given node.

pub fn new_opt<F>(rc: NodeRef, f: F) -> Option<NodeDataRef<T>>
where F: FnOnce(&Node) -> Option<&T>,

Create a NodeDataRef for and a component that may or may not be in a given node.

pub fn as_node(&self) -> &NodeRef

Access the corresponding node.

Source

impl NodeDataRef<ElementData>

Element-specific methods for NodeDataRef.

Provides convenience methods for working with element nodes.

pub fn text_contents(&self) -> String

Return the concatenation of all text nodes in this subtree.

pub fn local_name(&self) -> &LocalName

Returns the local name of the element without any namespace prefix.

Examples
use brik::parse_html;
use brik::traits::*;

let doc = parse_html().one("<div>Hello</div>");
let div = doc.select_first("div").unwrap();
assert_eq!(div.local_name().as_ref(), "div");